# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/neobotix_usboard_msgs/msg/command.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/neobotix_usboard_msgs/msg/command.proto\x12\x34make87_messages_ros2.jazzy.neobotix_usboard_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xbf\x02\n\x07\x43ommand\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\r\x12\x14\n\x0c\x63ommand_data\x18\x03 \x01(\x04\x12\x0f\n\x07set_num\x18\x04 \x01(\r\x12\x15\n\rparaset_byte6\x18\x05 \x01(\r\x12\x15\n\rparaset_byte5\x18\x06 \x01(\r\x12\x15\n\rparaset_byte4\x18\x07 \x01(\r\x12\x15\n\rparaset_byte3\x18\x08 \x01(\r\x12\x15\n\rparaset_byte2\x18\t \x01(\r\x12\x15\n\rparaset_byte1\x18\n \x01(\r\x12\x18\n\x10set_active_9to16\x18\x0b \x01(\r\x12\x17\n\x0fset_active_1to8\x18\x0c \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.neobotix_usboard_msgs.msg.command_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COMMAND']._serialized_start=179
  _globals['_COMMAND']._serialized_end=498
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geographic_msgs.msg import geo_point_pb2 as _geo_point_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ToLLRequest(_message.Message):
    __slots__ = ["header", "map_point"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_POINT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map_point: _point_pb2.Point
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map_point: _Optional[_Union[_point_pb2.Point, _Mapping]] = ...) -> None: ...

class ToLLResponse(_message.Message):
    __slots__ = ["header", "ll_point"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LL_POINT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ll_point: _geo_point_pb2.GeoPoint
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ll_point: _Optional[_Union[_geo_point_pb2.GeoPoint, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/msg/sensor_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import transform_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_transform__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import env_sensor_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_env__sensor__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import global_descriptor_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_global__descriptor__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import gps_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_gps__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import key_point_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_key__point__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import landmark_detection_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_landmark__detection__pb2
from make87_messages_ros2.jazzy.rtabmap_msgs.msg import point3f_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_point3f__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import camera_info_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_camera__info__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import image_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_image__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import imu_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_imu__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/jazzy/rtabmap_msgs/msg/sensor_data.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.msg\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a<make87_messages_ros2/jazzy/geometry_msgs/msg/transform.proto\x1a<make87_messages_ros2/jazzy/rtabmap_msgs/msg/env_sensor.proto\x1a\x43make87_messages_ros2/jazzy/rtabmap_msgs/msg/global_descriptor.proto\x1a\x35make87_messages_ros2/jazzy/rtabmap_msgs/msg/gps.proto\x1a;make87_messages_ros2/jazzy/rtabmap_msgs/msg/key_point.proto\x1a\x44make87_messages_ros2/jazzy/rtabmap_msgs/msg/landmark_detection.proto\x1a\x39make87_messages_ros2/jazzy/rtabmap_msgs/msg/point3f.proto\x1a<make87_messages_ros2/jazzy/sensor_msgs/msg/camera_info.proto\x1a\x36make87_messages_ros2/jazzy/sensor_msgs/msg/image.proto\x1a\x34make87_messages_ros2/jazzy/sensor_msgs/msg/imu.proto\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\x9c\r\n\nSensorData\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12?\n\x04left\x18\x02 \x01(\x0b\x32\x31.make87_messages_ros2.jazzy.sensor_msgs.msg.Image\x12@\n\x05right\x18\x03 \x01(\x0b\x32\x31.make87_messages_ros2.jazzy.sensor_msgs.msg.Image\x12\x17\n\x0fleft_compressed\x18\x04 \x03(\r\x12\x18\n\x10right_compressed\x18\x05 \x03(\r\x12P\n\x10left_camera_info\x18\x06 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.CameraInfo\x12Q\n\x11right_camera_info\x18\x07 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.sensor_msgs.msg.CameraInfo\x12P\n\x0flocal_transform\x18\x08 \x03(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12K\n\nlaser_scan\x18\t \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2\x12\x1d\n\x15laser_scan_compressed\x18\n \x03(\r\x12\x1a\n\x12laser_scan_max_pts\x18\x0b \x01(\x05\x12\x1c\n\x14laser_scan_max_range\x18\x0c \x01(\x02\x12\x19\n\x11laser_scan_format\x18\r \x01(\x05\x12[\n\x1alaser_scan_local_transform\x18\x0e \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12\x11\n\tuser_data\x18\x0f \x03(\r\x12\x13\n\x0bgrid_ground\x18\x10 \x03(\r\x12\x16\n\x0egrid_obstacles\x18\x11 \x03(\r\x12\x18\n\x10grid_empty_cells\x18\x12 \x03(\r\x12\x16\n\x0egrid_cell_size\x18\x13 \x01(\x02\x12M\n\x0fgrid_view_point\x18\x14 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Point3f\x12I\n\nkey_points\x18\x15 \x03(\x0b\x32\x35.make87_messages_ros2.jazzy.rtabmap_msgs.msg.KeyPoint\x12\x44\n\x06points\x18\x16 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.rtabmap_msgs.msg.Point3f\x12\x13\n\x0b\x64\x65scriptors\x18\x17 \x03(\r\x12Y\n\x12global_descriptors\x18\x18 \x03(\x0b\x32=.make87_messages_ros2.jazzy.rtabmap_msgs.msg.GlobalDescriptor\x12K\n\x0b\x65nv_sensors\x18\x19 \x03(\x0b\x32\x36.make87_messages_ros2.jazzy.rtabmap_msgs.msg.EnvSensor\x12<\n\x03imu\x18\x1a \x01(\x0b\x32/.make87_messages_ros2.jazzy.sensor_msgs.msg.Imu\x12T\n\x13imu_local_transform\x18\x1b \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.geometry_msgs.msg.Transform\x12Q\n\tlandmarks\x18\x1c \x03(\x0b\x32>.make87_messages_ros2.jazzy.rtabmap_msgs.msg.LandmarkDetection\x12M\n\x11ground_truth_pose\x18\x1d \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12=\n\x03gps\x18\x1e \x01(\x0b\x32\x30.make87_messages_ros2.jazzy.rtabmap_msgs.msg.GPSb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.msg.sensor_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SENSORDATA']._serialized_start=895
  _globals['_SENSORDATA']._serialized_end=2587
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import transform_pb2 as _transform_pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import env_sensor_pb2 as _env_sensor_pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import global_descriptor_pb2 as _global_descriptor_pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import gps_pb2 as _gps_pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import key_point_pb2 as _key_point_pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import landmark_detection_pb2 as _landmark_detection_pb2
from make87_messages_ros2.humble.rtabmap_msgs.msg import point3f_pb2 as _point3f_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import camera_info_pb2 as _camera_info_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import image_pb2 as _image_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import imu_pb2 as _imu_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as _point_cloud2_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SensorData(_message.Message):
    __slots__ = ["header", "ros2_header", "left", "right", "left_compressed", "right_compressed", "left_camera_info", "right_camera_info", "local_transform", "laser_scan", "laser_scan_compressed", "laser_scan_max_pts", "laser_scan_max_range", "laser_scan_format", "laser_scan_local_transform", "user_data", "grid_ground", "grid_obstacles", "grid_empty_cells", "grid_cell_size", "grid_view_point", "key_points", "points", "descriptors", "global_descriptors", "env_sensors", "imu", "imu_local_transform", "landmarks", "ground_truth_pose", "gps"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    LEFT_FIELD_NUMBER: _ClassVar[int]
    RIGHT_FIELD_NUMBER: _ClassVar[int]
    LEFT_COMPRESSED_FIELD_NUMBER: _ClassVar[int]
    RIGHT_COMPRESSED_FIELD_NUMBER: _ClassVar[int]
    LEFT_CAMERA_INFO_FIELD_NUMBER: _ClassVar[int]
    RIGHT_CAMERA_INFO_FIELD_NUMBER: _ClassVar[int]
    LOCAL_TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    LASER_SCAN_FIELD_NUMBER: _ClassVar[int]
    LASER_SCAN_COMPRESSED_FIELD_NUMBER: _ClassVar[int]
    LASER_SCAN_MAX_PTS_FIELD_NUMBER: _ClassVar[int]
    LASER_SCAN_MAX_RANGE_FIELD_NUMBER: _ClassVar[int]
    LASER_SCAN_FORMAT_FIELD_NUMBER: _ClassVar[int]
    LASER_SCAN_LOCAL_TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    USER_DATA_FIELD_NUMBER: _ClassVar[int]
    GRID_GROUND_FIELD_NUMBER: _ClassVar[int]
    GRID_OBSTACLES_FIELD_NUMBER: _ClassVar[int]
    GRID_EMPTY_CELLS_FIELD_NUMBER: _ClassVar[int]
    GRID_CELL_SIZE_FIELD_NUMBER: _ClassVar[int]
    GRID_VIEW_POINT_FIELD_NUMBER: _ClassVar[int]
    KEY_POINTS_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTORS_FIELD_NUMBER: _ClassVar[int]
    GLOBAL_DESCRIPTORS_FIELD_NUMBER: _ClassVar[int]
    ENV_SENSORS_FIELD_NUMBER: _ClassVar[int]
    IMU_FIELD_NUMBER: _ClassVar[int]
    IMU_LOCAL_TRANSFORM_FIELD_NUMBER: _ClassVar[int]
    LANDMARKS_FIELD_NUMBER: _ClassVar[int]
    GROUND_TRUTH_POSE_FIELD_NUMBER: _ClassVar[int]
    GPS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    left: _image_pb2.Image
    right: _image_pb2.Image
    left_compressed: _containers.RepeatedScalarFieldContainer[int]
    right_compressed: _containers.RepeatedScalarFieldContainer[int]
    left_camera_info: _containers.RepeatedCompositeFieldContainer[_camera_info_pb2.CameraInfo]
    right_camera_info: _containers.RepeatedCompositeFieldContainer[_camera_info_pb2.CameraInfo]
    local_transform: _containers.RepeatedCompositeFieldContainer[_transform_pb2.Transform]
    laser_scan: _point_cloud2_pb2.PointCloud2
    laser_scan_compressed: _containers.RepeatedScalarFieldContainer[int]
    laser_scan_max_pts: int
    laser_scan_max_range: float
    laser_scan_format: int
    laser_scan_local_transform: _transform_pb2.Transform
    user_data: _containers.RepeatedScalarFieldContainer[int]
    grid_ground: _containers.RepeatedScalarFieldContainer[int]
    grid_obstacles: _containers.RepeatedScalarFieldContainer[int]
    grid_empty_cells: _containers.RepeatedScalarFieldContainer[int]
    grid_cell_size: float
    grid_view_point: _point3f_pb2.Point3f
    key_points: _containers.RepeatedCompositeFieldContainer[_key_point_pb2.KeyPoint]
    points: _containers.RepeatedCompositeFieldContainer[_point3f_pb2.Point3f]
    descriptors: _containers.RepeatedScalarFieldContainer[int]
    global_descriptors: _containers.RepeatedCompositeFieldContainer[_global_descriptor_pb2.GlobalDescriptor]
    env_sensors: _containers.RepeatedCompositeFieldContainer[_env_sensor_pb2.EnvSensor]
    imu: _imu_pb2.Imu
    imu_local_transform: _transform_pb2.Transform
    landmarks: _containers.RepeatedCompositeFieldContainer[_landmark_detection_pb2.LandmarkDetection]
    ground_truth_pose: _pose_pb2.Pose
    gps: _gps_pb2.GPS
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., left: _Optional[_Union[_image_pb2.Image, _Mapping]] = ..., right: _Optional[_Union[_image_pb2.Image, _Mapping]] = ..., left_compressed: _Optional[_Iterable[int]] = ..., right_compressed: _Optional[_Iterable[int]] = ..., left_camera_info: _Optional[_Iterable[_Union[_camera_info_pb2.CameraInfo, _Mapping]]] = ..., right_camera_info: _Optional[_Iterable[_Union[_camera_info_pb2.CameraInfo, _Mapping]]] = ..., local_transform: _Optional[_Iterable[_Union[_transform_pb2.Transform, _Mapping]]] = ..., laser_scan: _Optional[_Union[_point_cloud2_pb2.PointCloud2, _Mapping]] = ..., laser_scan_compressed: _Optional[_Iterable[int]] = ..., laser_scan_max_pts: _Optional[int] = ..., laser_scan_max_range: _Optional[float] = ..., laser_scan_format: _Optional[int] = ..., laser_scan_local_transform: _Optional[_Union[_transform_pb2.Transform, _Mapping]] = ..., user_data: _Optional[_Iterable[int]] = ..., grid_ground: _Optional[_Iterable[int]] = ..., grid_obstacles: _Optional[_Iterable[int]] = ..., grid_empty_cells: _Optional[_Iterable[int]] = ..., grid_cell_size: _Optional[float] = ..., grid_view_point: _Optional[_Union[_point3f_pb2.Point3f, _Mapping]] = ..., key_points: _Optional[_Iterable[_Union[_key_point_pb2.KeyPoint, _Mapping]]] = ..., points: _Optional[_Iterable[_Union[_point3f_pb2.Point3f, _Mapping]]] = ..., descriptors: _Optional[_Iterable[int]] = ..., global_descriptors: _Optional[_Iterable[_Union[_global_descriptor_pb2.GlobalDescriptor, _Mapping]]] = ..., env_sensors: _Optional[_Iterable[_Union[_env_sensor_pb2.EnvSensor, _Mapping]]] = ..., imu: _Optional[_Union[_imu_pb2.Imu, _Mapping]] = ..., imu_local_transform: _Optional[_Union[_transform_pb2.Transform, _Mapping]] = ..., landmarks: _Optional[_Iterable[_Union[_landmark_detection_pb2.LandmarkDetection, _Mapping]]] = ..., ground_truth_pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., gps: _Optional[_Union[_gps_pb2.GPS, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_map_msgs/msg/area_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/autoware_map_msgs/msg/area_info.proto\x12\x32make87_messages_ros2.rolling.autoware_map_msgs.msg\">\n\x08\x41reaInfo\x12\x10\n\x08\x63\x65nter_x\x18\x01 \x01(\x02\x12\x10\n\x08\x63\x65nter_y\x18\x02 \x01(\x02\x12\x0e\n\x06radius\x18\x03 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_map_msgs.msg.area_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_AREAINFO']._serialized_start=122
  _globals['_AREAINFO']._serialized_end=184
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.geographic_msgs.msg import geo_pose_with_covariance_pb2 as _geo_pose_with_covariance_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GeoPoseWithCovarianceStamped(_message.Message):
    __slots__ = ["header", "pose"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    pose: _geo_pose_with_covariance_pb2.GeoPoseWithCovariance
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., pose: _Optional[_Union[_geo_pose_with_covariance_pb2.GeoPoseWithCovariance, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.ur_dashboard_msgs.msg import robot_mode_pb2 as _robot_mode_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetRobotModeRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetRobotModeResponse(_message.Message):
    __slots__ = ["robot_mode", "answer", "success"]
    ROBOT_MODE_FIELD_NUMBER: _ClassVar[int]
    ANSWER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    robot_mode: _robot_mode_pb2.RobotMode
    answer: str
    success: bool
    def __init__(self, robot_mode: _Optional[_Union[_robot_mode_pb2.RobotMode, _Mapping]] = ..., answer: _Optional[str] = ..., success: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ActionPerformerStatus(_message.Message):
    __slots__ = ["header", "status_stamp", "state", "action", "specialized_arguments", "node_name"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATUS_STAMP_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    SPECIALIZED_ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    NODE_NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    status_stamp: _time_pb2.Time
    state: int
    action: str
    specialized_arguments: _containers.RepeatedScalarFieldContainer[str]
    node_name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., status_stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., state: _Optional[int] = ..., action: _Optional[str] = ..., specialized_arguments: _Optional[_Iterable[str]] = ..., node_name: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.automotive_navigation_msgs.msg import lane_boundary_pb2 as _lane_boundary_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LaneBoundaryArray(_message.Message):
    __slots__ = ["boundaries"]
    BOUNDARIES_FIELD_NUMBER: _ClassVar[int]
    boundaries: _containers.RepeatedCompositeFieldContainer[_lane_boundary_pb2.LaneBoundary]
    def __init__(self, boundaries: _Optional[_Iterable[_Union[_lane_boundary_pb2.LaneBoundary, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrafficSignalElement(_message.Message):
    __slots__ = ["header", "color", "shape", "status", "confidence"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    SHAPE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    color: int
    shape: int
    status: int
    confidence: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., color: _Optional[int] = ..., shape: _Optional[int] = ..., status: _Optional[int] = ..., confidence: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ibeo_msgs/msg/scanner_info2205.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_humble_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import mounting_position_f_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_mounting__position__f__pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import resolution_info_pb2 as make87__messages__ros2_dot_humble_dot_ibeo__msgs_dot_msg_dot_resolution__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/ibeo_msgs/msg/scanner_info2205.proto\x12)make87_messages_ros2.humble.ibeo_msgs.msg\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/builtin_interfaces/msg/time.proto\x1a\x43make87_messages_ros2/humble/ibeo_msgs/msg/mounting_position_f.proto\x1a?make87_messages_ros2/humble/ibeo_msgs/msg/resolution_info.proto\"\xed\x05\n\x0fScannerInfo2205\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x14\n\x0cscanner_type\x18\x03 \x01(\r\x12\x13\n\x0bscan_number\x18\x04 \x01(\r\x12\x13\n\x0bstart_angle\x18\x05 \x01(\x02\x12\x11\n\tend_angle\x18\x06 \x01(\x02\x12Q\n\x0fscan_start_time\x18\x07 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12O\n\rscan_end_time\x18\x08 \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12]\n\x1bscan_start_time_from_device\x18\t \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12[\n\x19scan_end_time_from_device\x18\n \x01(\x0b\x32\x38.make87_messages_ros2.humble.builtin_interfaces.msg.Time\x12\x16\n\x0escan_frequency\x18\x0b \x01(\x02\x12\x11\n\tbeam_tilt\x18\x0c \x01(\x02\x12\x12\n\nscan_flags\x18\r \x01(\r\x12W\n\x11mounting_position\x18\x0e \x01(\x0b\x32<.make87_messages_ros2.humble.ibeo_msgs.msg.MountingPositionF\x12N\n\x0bresolutions\x18\x0f \x03(\x0b\x32\x39.make87_messages_ros2.humble.ibeo_msgs.msg.ResolutionInfob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ibeo_msgs.msg.scanner_info2205_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANNERINFO2205']._serialized_start=344
  _globals['_SCANNERINFO2205']._serialized_end=1093
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import ball_pb2 as _ball_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import field_line_pb2 as _field_line_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import flag_pb2 as _flag_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import goalpost_pb2 as _goalpost_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import player_pb2 as _player_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Vision(_message.Message):
    __slots__ = ["header", "ball", "field_lines", "flags", "goalposts", "players"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BALL_FIELD_NUMBER: _ClassVar[int]
    FIELD_LINES_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    GOALPOSTS_FIELD_NUMBER: _ClassVar[int]
    PLAYERS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ball: _containers.RepeatedCompositeFieldContainer[_ball_pb2.Ball]
    field_lines: _containers.RepeatedCompositeFieldContainer[_field_line_pb2.FieldLine]
    flags: _containers.RepeatedCompositeFieldContainer[_flag_pb2.Flag]
    goalposts: _containers.RepeatedCompositeFieldContainer[_goalpost_pb2.Goalpost]
    players: _containers.RepeatedCompositeFieldContainer[_player_pb2.Player]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ball: _Optional[_Iterable[_Union[_ball_pb2.Ball, _Mapping]]] = ..., field_lines: _Optional[_Iterable[_Union[_field_line_pb2.FieldLine, _Mapping]]] = ..., flags: _Optional[_Iterable[_Union[_flag_pb2.Flag, _Mapping]]] = ..., goalposts: _Optional[_Iterable[_Union[_goalpost_pb2.Goalpost, _Mapping]]] = ..., players: _Optional[_Iterable[_Union[_player_pb2.Player, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/map_msgs/srv/get_map_roi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.nav_msgs.msg import occupancy_grid_pb2 as make87__messages__ros2_dot_humble_dot_nav__msgs_dot_msg_dot_occupancy__grid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/humble/map_msgs/srv/get_map_roi.proto\x12(make87_messages_ros2.humble.map_msgs.srv\x1a!make87_messages/core/header.proto\x1a=make87_messages_ros2/humble/nav_msgs/msg/occupancy_grid.proto\"p\n\x10GetMapROIRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\x0b\n\x03l_x\x18\x04 \x01(\x01\x12\x0b\n\x03l_y\x18\x05 \x01(\x01\"\x8b\x01\n\x11GetMapROIResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12H\n\x07sub_map\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.humble.nav_msgs.msg.OccupancyGridb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.map_msgs.srv.get_map_roi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETMAPROIREQUEST']._serialized_start=202
  _globals['_GETMAPROIREQUEST']._serialized_end=314
  _globals['_GETMAPROIRESPONSE']._serialized_start=317
  _globals['_GETMAPROIRESPONSE']._serialized_end=456
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class KeyValue(_message.Message):
    __slots__ = ["key", "value"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BeaconState(_message.Message):
    __slots__ = ["id", "online", "category", "activated", "level"]
    ID_FIELD_NUMBER: _ClassVar[int]
    ONLINE_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    ACTIVATED_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    id: str
    online: bool
    category: str
    activated: bool
    level: str
    def __init__(self, id: _Optional[str] = ..., online: bool = ..., category: _Optional[str] = ..., activated: bool = ..., level: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marine_acoustic_msgs/msg/raw_sonar_image.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.marine_acoustic_msgs.msg import ping_info_pb2 as make87__messages__ros2_dot_rolling_dot_marine__acoustic__msgs_dot_msg_dot_ping__info__pb2
from make87_messages_ros2.rolling.marine_acoustic_msgs.msg import sonar_image_data_pb2 as make87__messages__ros2_dot_rolling_dot_marine__acoustic__msgs_dot_msg_dot_sonar__image__data__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/rolling/marine_acoustic_msgs/msg/raw_sonar_image.proto\x12\x35make87_messages_ros2.rolling.marine_acoustic_msgs.msg\x1a\x45make87_messages_ros2/rolling/marine_acoustic_msgs/msg/ping_info.proto\x1aLmake87_messages_ros2/rolling/marine_acoustic_msgs/msg/sonar_image_data.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xf5\x02\n\rRawSonarImage\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12R\n\tping_info\x18\x02 \x01(\x0b\x32?.make87_messages_ros2.rolling.marine_acoustic_msgs.msg.PingInfo\x12\x13\n\x0bsample_rate\x18\x03 \x01(\x02\x12\x18\n\x10samples_per_beam\x18\x04 \x01(\r\x12\x0f\n\x07sample0\x18\x05 \x01(\r\x12\x11\n\ttx_delays\x18\x06 \x03(\x02\x12\x11\n\ttx_angles\x18\x07 \x03(\x02\x12\x11\n\trx_angles\x18\x08 \x03(\x02\x12T\n\x05image\x18\t \x01(\x0b\x32\x45.make87_messages_ros2.rolling.marine_acoustic_msgs.msg.SonarImageDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marine_acoustic_msgs.msg.raw_sonar_image_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RAWSONARIMAGE']._serialized_start=340
  _globals['_RAWSONARIMAGE']._serialized_end=713
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/goalpost.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg import spherical_pb2 as make87__messages__ros2_dot_jazzy_dot_rcss3d__agent__msgs_dot_msg_dot_spherical__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/goalpost.proto\x12\x30make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg\x1a@make87_messages_ros2/jazzy/rcss3d_agent_msgs/msg/spherical.proto\"b\n\x08Goalpost\x12\x0c\n\x04name\x18\x01 \x01(\t\x12H\n\x03top\x18\x02 \x01(\x0b\x32;.make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.Sphericalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rcss3d_agent_msgs.msg.goalpost_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GOALPOST']._serialized_start=183
  _globals['_GOALPOST']._serialized_end=281
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.visualization_msgs.msg import interactive_marker_control_pb2 as _interactive_marker_control_pb2
from make87_messages_ros2.rolling.visualization_msgs.msg import menu_entry_pb2 as _menu_entry_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InteractiveMarker(_message.Message):
    __slots__ = ["header", "pose", "name", "description", "scale", "menu_entries", "controls"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SCALE_FIELD_NUMBER: _ClassVar[int]
    MENU_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    CONTROLS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    pose: _pose_pb2.Pose
    name: str
    description: str
    scale: float
    menu_entries: _containers.RepeatedCompositeFieldContainer[_menu_entry_pb2.MenuEntry]
    controls: _containers.RepeatedCompositeFieldContainer[_interactive_marker_control_pb2.InteractiveMarkerControl]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., scale: _Optional[float] = ..., menu_entries: _Optional[_Iterable[_Union[_menu_entry_pb2.MenuEntry, _Mapping]]] = ..., controls: _Optional[_Iterable[_Union[_interactive_marker_control_pb2.InteractiveMarkerControl, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/py_trees_ros_interfaces/srv/get_blackboard_variables.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWmake87_messages_ros2/rolling/py_trees_ros_interfaces/srv/get_blackboard_variables.proto\x12\x38make87_messages_ros2.rolling.py_trees_ros_interfaces.srv\"\x1f\n\x1dGetBlackboardVariablesRequest\"3\n\x1eGetBlackboardVariablesResponse\x12\x11\n\tvariables\x18\x01 \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.py_trees_ros_interfaces.srv.get_blackboard_variables_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETBLACKBOARDVARIABLESREQUEST']._serialized_start=149
  _globals['_GETBLACKBOARDVARIABLESREQUEST']._serialized_end=180
  _globals['_GETBLACKBOARDVARIABLESRESPONSE']._serialized_start=182
  _globals['_GETBLACKBOARDVARIABLESRESPONSE']._serialized_end=233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/py_trees_ros_interfaces/msg/behaviour.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import key_value_pb2 as make87__messages__ros2_dot_rolling_dot_py__trees__ros__interfaces_dot_msg_dot_key__value__pb2
from make87_messages_ros2.rolling.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_rolling_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/behaviour.proto\x12\x38make87_messages_ros2.rolling.py_trees_ros_interfaces.msg\x1aHmake87_messages_ros2/rolling/py_trees_ros_interfaces/msg/key_value.proto\x1a\x42make87_messages_ros2/rolling/unique_identifier_msgs/msg/uuid.proto\"\x9c\x05\n\tBehaviour\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nclass_name\x18\x02 \x01(\t\x12M\n\x06own_id\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12P\n\tparent_id\x18\x04 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12M\n\x06tip_id\x18\x05 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12P\n\tchild_ids\x18\x06 \x03(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12W\n\x10\x63urrent_child_id\x18\x07 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12\x0c\n\x04type\x18\x08 \x01(\r\x12\x19\n\x11\x61\x64\x64itional_detail\x18\t \x01(\t\x12\x16\n\x0e\x62lackbox_level\x18\n \x01(\r\x12\x0e\n\x06status\x18\x0b \x01(\r\x12\x0f\n\x07message\x18\x0c \x01(\t\x12\x11\n\tis_active\x18\r \x01(\x08\x12]\n\x11\x62lackboard_access\x18\x0e \x03(\x0b\x32\x42.make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.KeyValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.py_trees_ros_interfaces.msg.behaviour_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BEHAVIOUR']._serialized_start=277
  _globals['_BEHAVIOUR']._serialized_end=945
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import joint_state_pb2 as _joint_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CaptureConfig(_message.Message):
    __slots__ = ["header", "joint_states", "features"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    JOINT_STATES_FIELD_NUMBER: _ClassVar[int]
    FEATURES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    joint_states: _joint_state_pb2.JointState
    features: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., joint_states: _Optional[_Union[_joint_state_pb2.JointState, _Mapping]] = ..., features: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DriveFeedback(_message.Message):
    __slots__ = ["header", "current", "duty_cycle", "bridge_temperature", "motor_temperature", "measured_velocity", "measured_travel", "driver_fault"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    DUTY_CYCLE_FIELD_NUMBER: _ClassVar[int]
    BRIDGE_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    MOTOR_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    MEASURED_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    MEASURED_TRAVEL_FIELD_NUMBER: _ClassVar[int]
    DRIVER_FAULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    current: float
    duty_cycle: float
    bridge_temperature: float
    motor_temperature: float
    measured_velocity: float
    measured_travel: float
    driver_fault: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., current: _Optional[float] = ..., duty_cycle: _Optional[float] = ..., bridge_temperature: _Optional[float] = ..., motor_temperature: _Optional[float] = ..., measured_velocity: _Optional[float] = ..., measured_travel: _Optional[float] = ..., driver_fault: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UserInputMedia(_message.Message):
    __slots__ = ["header", "ros2_header", "btn_vol_up", "btn_vol_down", "btn_mute", "btn_next", "btn_prev", "btn_next_hang_up", "btn_prev_answer", "btn_hang_up", "btn_answer", "btn_play", "btn_pause", "btn_play_pause", "btn_mode"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    BTN_VOL_UP_FIELD_NUMBER: _ClassVar[int]
    BTN_VOL_DOWN_FIELD_NUMBER: _ClassVar[int]
    BTN_MUTE_FIELD_NUMBER: _ClassVar[int]
    BTN_NEXT_FIELD_NUMBER: _ClassVar[int]
    BTN_PREV_FIELD_NUMBER: _ClassVar[int]
    BTN_NEXT_HANG_UP_FIELD_NUMBER: _ClassVar[int]
    BTN_PREV_ANSWER_FIELD_NUMBER: _ClassVar[int]
    BTN_HANG_UP_FIELD_NUMBER: _ClassVar[int]
    BTN_ANSWER_FIELD_NUMBER: _ClassVar[int]
    BTN_PLAY_FIELD_NUMBER: _ClassVar[int]
    BTN_PAUSE_FIELD_NUMBER: _ClassVar[int]
    BTN_PLAY_PAUSE_FIELD_NUMBER: _ClassVar[int]
    BTN_MODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    btn_vol_up: bool
    btn_vol_down: bool
    btn_mute: bool
    btn_next: bool
    btn_prev: bool
    btn_next_hang_up: bool
    btn_prev_answer: bool
    btn_hang_up: bool
    btn_answer: bool
    btn_play: bool
    btn_pause: bool
    btn_play_pause: bool
    btn_mode: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., btn_vol_up: bool = ..., btn_vol_down: bool = ..., btn_mute: bool = ..., btn_next: bool = ..., btn_prev: bool = ..., btn_next_hang_up: bool = ..., btn_prev_answer: bool = ..., btn_hang_up: bool = ..., btn_answer: bool = ..., btn_play: bool = ..., btn_pause: bool = ..., btn_play_pause: bool = ..., btn_mode: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rcss3d_agent_msgs/msg/universal_joint_vel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLmake87_messages_ros2/rolling/rcss3d_agent_msgs/msg/universal_joint_vel.proto\x12\x32make87_messages_ros2.rolling.rcss3d_agent_msgs.msg\";\n\x11UniversalJointVel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x61x1\x18\x02 \x01(\x02\x12\x0b\n\x03\x61x2\x18\x03 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rcss3d_agent_msgs.msg.universal_joint_vel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UNIVERSALJOINTVEL']._serialized_start=132
  _globals['_UNIVERSALJOINTVEL']._serialized_end=191
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Sigma2D(_message.Message):
    __slots__ = ["sigma_x", "sigma_y"]
    SIGMA_X_FIELD_NUMBER: _ClassVar[int]
    SIGMA_Y_FIELD_NUMBER: _ClassVar[int]
    sigma_x: int
    sigma_y: int
    def __init__(self, sigma_x: _Optional[int] = ..., sigma_y: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PVTGeodetic(_message.Message):
    __slots__ = ["header", "block_header", "mode", "error", "latitude", "longitude", "height", "undulation", "vn", "ve", "vu", "cog", "rx_clk_bias", "rx_clk_drift", "time_system", "datum", "nr_sv", "wa_corr_info", "reference_id", "mean_corr_age", "signal_info", "alert_flag", "nr_bases", "ppp_info", "latency", "h_accuracy", "v_accuracy", "misc"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    LATITUDE_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    UNDULATION_FIELD_NUMBER: _ClassVar[int]
    VN_FIELD_NUMBER: _ClassVar[int]
    VE_FIELD_NUMBER: _ClassVar[int]
    VU_FIELD_NUMBER: _ClassVar[int]
    COG_FIELD_NUMBER: _ClassVar[int]
    RX_CLK_BIAS_FIELD_NUMBER: _ClassVar[int]
    RX_CLK_DRIFT_FIELD_NUMBER: _ClassVar[int]
    TIME_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    DATUM_FIELD_NUMBER: _ClassVar[int]
    NR_SV_FIELD_NUMBER: _ClassVar[int]
    WA_CORR_INFO_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_ID_FIELD_NUMBER: _ClassVar[int]
    MEAN_CORR_AGE_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_INFO_FIELD_NUMBER: _ClassVar[int]
    ALERT_FLAG_FIELD_NUMBER: _ClassVar[int]
    NR_BASES_FIELD_NUMBER: _ClassVar[int]
    PPP_INFO_FIELD_NUMBER: _ClassVar[int]
    LATENCY_FIELD_NUMBER: _ClassVar[int]
    H_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    V_ACCURACY_FIELD_NUMBER: _ClassVar[int]
    MISC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    mode: int
    error: int
    latitude: float
    longitude: float
    height: float
    undulation: float
    vn: float
    ve: float
    vu: float
    cog: float
    rx_clk_bias: float
    rx_clk_drift: float
    time_system: int
    datum: int
    nr_sv: int
    wa_corr_info: int
    reference_id: int
    mean_corr_age: int
    signal_info: int
    alert_flag: int
    nr_bases: int
    ppp_info: int
    latency: int
    h_accuracy: int
    v_accuracy: int
    misc: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., mode: _Optional[int] = ..., error: _Optional[int] = ..., latitude: _Optional[float] = ..., longitude: _Optional[float] = ..., height: _Optional[float] = ..., undulation: _Optional[float] = ..., vn: _Optional[float] = ..., ve: _Optional[float] = ..., vu: _Optional[float] = ..., cog: _Optional[float] = ..., rx_clk_bias: _Optional[float] = ..., rx_clk_drift: _Optional[float] = ..., time_system: _Optional[int] = ..., datum: _Optional[int] = ..., nr_sv: _Optional[int] = ..., wa_corr_info: _Optional[int] = ..., reference_id: _Optional[int] = ..., mean_corr_age: _Optional[int] = ..., signal_info: _Optional[int] = ..., alert_flag: _Optional[int] = ..., nr_bases: _Optional[int] = ..., ppp_info: _Optional[int] = ..., latency: _Optional[int] = ..., h_accuracy: _Optional[int] = ..., v_accuracy: _Optional[int] = ..., misc: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.sensor_msgs.msg import image_pb2 as _image_pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import region_of_interest_pb2 as _region_of_interest_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DisparityImage(_message.Message):
    __slots__ = ["header", "image", "f", "t", "valid_window", "min_disparity", "max_disparity", "delta_d"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    F_FIELD_NUMBER: _ClassVar[int]
    T_FIELD_NUMBER: _ClassVar[int]
    VALID_WINDOW_FIELD_NUMBER: _ClassVar[int]
    MIN_DISPARITY_FIELD_NUMBER: _ClassVar[int]
    MAX_DISPARITY_FIELD_NUMBER: _ClassVar[int]
    DELTA_D_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    image: _image_pb2.Image
    f: float
    t: float
    valid_window: _region_of_interest_pb2.RegionOfInterest
    min_disparity: float
    max_disparity: float
    delta_d: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., image: _Optional[_Union[_image_pb2.Image, _Mapping]] = ..., f: _Optional[float] = ..., t: _Optional[float] = ..., valid_window: _Optional[_Union[_region_of_interest_pb2.RegionOfInterest, _Mapping]] = ..., min_disparity: _Optional[float] = ..., max_disparity: _Optional[float] = ..., delta_d: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_nav_msgs/srv/get_route_list.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.marti_nav_msgs.msg import route_pb2 as make87__messages__ros2_dot_rolling_dot_marti__nav__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/marti_nav_msgs/srv/get_route_list.proto\x12/make87_messages_ros2.rolling.marti_nav_msgs.srv\x1a;make87_messages_ros2/rolling/marti_nav_msgs/msg/route.proto\"\x15\n\x13GetRouteListRequest\"\x80\x01\n\x14GetRouteListResponse\x12\x46\n\x06routes\x18\x01 \x03(\x0b\x32\x36.make87_messages_ros2.rolling.marti_nav_msgs.msg.Route\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0f\n\x07message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_nav_msgs.srv.get_route_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETROUTELISTREQUEST']._serialized_start=182
  _globals['_GETROUTELISTREQUEST']._serialized_end=203
  _globals['_GETROUTELISTRESPONSE']._serialized_start=206
  _globals['_GETROUTELISTRESPONSE']._serialized_end=334
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/canopen_interfaces/srv/co_target_double.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/canopen_interfaces/srv/co_target_double.proto\x12\x33make87_messages_ros2.rolling.canopen_interfaces.srv\"\'\n\x15\x43OTargetDoubleRequest\x12\x0e\n\x06target\x18\x01 \x01(\x01\")\n\x16\x43OTargetDoubleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.canopen_interfaces.srv.co_target_double_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_COTARGETDOUBLEREQUEST']._serialized_start=131
  _globals['_COTARGETDOUBLEREQUEST']._serialized_end=170
  _globals['_COTARGETDOUBLERESPONSE']._serialized_start=172
  _globals['_COTARGETDOUBLERESPONSE']._serialized_end=213
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/get_planner_params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import planner_params_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_planner__params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/moveit_msgs/srv/get_planner_params.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\x1a?make87_messages_ros2/jazzy/moveit_msgs/msg/planner_params.proto\"U\n\x17GetPlannerParamsRequest\x12\x13\n\x0bpipeline_id\x18\x01 \x01(\t\x12\x16\n\x0eplanner_config\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\"e\n\x18GetPlannerParamsResponse\x12I\n\x06params\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.moveit_msgs.msg.PlannerParamsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.get_planner_params_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETPLANNERPARAMSREQUEST']._serialized_start=180
  _globals['_GETPLANNERPARAMSREQUEST']._serialized_end=265
  _globals['_GETPLANNERPARAMSRESPONSE']._serialized_start=267
  _globals['_GETPLANNERPARAMSRESPONSE']._serialized_end=368
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rcl_interfaces/srv/get_logger_levels.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rcl_interfaces.msg import logger_level_pb2 as make87__messages__ros2_dot_jazzy_dot_rcl__interfaces_dot_msg_dot_logger__level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rcl_interfaces/srv/get_logger_levels.proto\x12-make87_messages_ros2.jazzy.rcl_interfaces.srv\x1a@make87_messages_ros2/jazzy/rcl_interfaces/msg/logger_level.proto\"\'\n\x16GetLoggerLevelsRequest\x12\r\n\x05names\x18\x01 \x03(\t\"e\n\x17GetLoggerLevelsResponse\x12J\n\x06levels\x18\x01 \x03(\x0b\x32:.make87_messages_ros2.jazzy.rcl_interfaces.msg.LoggerLevelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rcl_interfaces.srv.get_logger_levels_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETLOGGERLEVELSREQUEST']._serialized_start=186
  _globals['_GETLOGGERLEVELSREQUEST']._serialized_end=225
  _globals['_GETLOGGERLEVELSRESPONSE']._serialized_start=227
  _globals['_GETLOGGERLEVELSRESPONSE']._serialized_end=328
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Inscov(_message.Message):
    __slots__ = ["header", "ros2_header", "novatel_msg_header", "week", "seconds", "position_covariance", "attitude_covariance", "velocity_covariance"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    WEEK_FIELD_NUMBER: _ClassVar[int]
    SECONDS_FIELD_NUMBER: _ClassVar[int]
    POSITION_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    ATTITUDE_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    week: int
    seconds: float
    position_covariance: _containers.RepeatedScalarFieldContainer[float]
    attitude_covariance: _containers.RepeatedScalarFieldContainer[float]
    velocity_covariance: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., week: _Optional[int] = ..., seconds: _Optional[float] = ..., position_covariance: _Optional[_Iterable[float]] = ..., attitude_covariance: _Optional[_Iterable[float]] = ..., velocity_covariance: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Image(_message.Message):
    __slots__ = ["header", "height", "width", "encoding", "is_bigendian", "step", "data"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    ENCODING_FIELD_NUMBER: _ClassVar[int]
    IS_BIGENDIAN_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    height: int
    width: int
    encoding: str
    is_bigendian: int
    step: int
    data: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., height: _Optional[int] = ..., width: _Optional[int] = ..., encoding: _Optional[str] = ..., is_bigendian: _Optional[int] = ..., step: _Optional[int] = ..., data: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/msg/load_carrier_with_filling_level.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_stamped_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__stamped__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import box_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_box__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import cell_filling_level_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_cell__filling__level__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import grid_size_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_grid__size__pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import rectangle_pb2 as make87__messages__ros2_dot_rolling_dot_rc__reason__msgs_dot_msg_dot_rectangle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUmake87_messages_ros2/rolling/rc_reason_msgs/msg/load_carrier_with_filling_level.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.msg\x1a\x41make87_messages_ros2/rolling/geometry_msgs/msg/pose_stamped.proto\x1a\x39make87_messages_ros2/rolling/rc_reason_msgs/msg/box.proto\x1aHmake87_messages_ros2/rolling/rc_reason_msgs/msg/cell_filling_level.proto\x1a?make87_messages_ros2/rolling/rc_reason_msgs/msg/grid_size.proto\x1a?make87_messages_ros2/rolling/rc_reason_msgs/msg/rectangle.proto\"\xab\x06\n\x1bLoadCarrierWithFillingLevel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12N\n\x10outer_dimensions\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.rc_reason_msgs.msg.Box\x12N\n\x10inner_dimensions\x18\x04 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.rc_reason_msgs.msg.Box\x12Q\n\rrim_thickness\x18\x05 \x01(\x0b\x32:.make87_messages_ros2.rolling.rc_reason_msgs.msg.Rectangle\x12\x17\n\x0frim_step_height\x18\x06 \x01(\x01\x12M\n\trim_ledge\x18\x07 \x01(\x0b\x32:.make87_messages_ros2.rolling.rc_reason_msgs.msg.Rectangle\x12\x18\n\x10height_open_side\x18\x08 \x01(\x01\x12I\n\x04pose\x18\t \x01(\x0b\x32;.make87_messages_ros2.rolling.geometry_msgs.msg.PoseStamped\x12\x12\n\noverfilled\x18\n \x01(\x08\x12`\n\x15overall_filling_level\x18\x0b \x01(\x0b\x32\x41.make87_messages_ros2.rolling.rc_reason_msgs.msg.CellFillingLevel\x12_\n\x14\x63\x65lls_filling_levels\x18\x0c \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rc_reason_msgs.msg.CellFillingLevel\x12[\n\x18\x66illing_level_cell_count\x18\r \x01(\x0b\x32\x39.make87_messages_ros2.rolling.rc_reason_msgs.msg.GridSizeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.msg.load_carrier_with_filling_level_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOADCARRIERWITHFILLINGLEVEL']._serialized_start=469
  _globals['_LOADCARRIERWITHFILLINGLEVEL']._serialized_end=1280
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.nmea_msgs.msg import gpgsv_satellite_pb2 as _gpgsv_satellite_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Gpgsv(_message.Message):
    __slots__ = ["header", "ros2_header", "message_id", "n_msgs", "msg_number", "n_satellites", "satellites"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    N_MSGS_FIELD_NUMBER: _ClassVar[int]
    MSG_NUMBER_FIELD_NUMBER: _ClassVar[int]
    N_SATELLITES_FIELD_NUMBER: _ClassVar[int]
    SATELLITES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    message_id: str
    n_msgs: int
    msg_number: int
    n_satellites: int
    satellites: _containers.RepeatedCompositeFieldContainer[_gpgsv_satellite_pb2.GpgsvSatellite]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., message_id: _Optional[str] = ..., n_msgs: _Optional[int] = ..., msg_number: _Optional[int] = ..., n_satellites: _Optional[int] = ..., satellites: _Optional[_Iterable[_Union[_gpgsv_satellite_pb2.GpgsvSatellite, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.mavros_msgs.msg import waypoint_pb2 as _waypoint_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WaypointList(_message.Message):
    __slots__ = ["current_seq", "waypoints"]
    CURRENT_SEQ_FIELD_NUMBER: _ClassVar[int]
    WAYPOINTS_FIELD_NUMBER: _ClassVar[int]
    current_seq: int
    waypoints: _containers.RepeatedCompositeFieldContainer[_waypoint_pb2.Waypoint]
    def __init__(self, current_seq: _Optional[int] = ..., waypoints: _Optional[_Iterable[_Union[_waypoint_pb2.Waypoint, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import error_pb2 as _error_pb2
from make87_messages_ros2.humble.vimbax_camera_msgs.msg import trigger_info_pb2 as _trigger_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StatusRequest(_message.Message):
    __slots__ = ["header"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...

class StatusResponse(_message.Message):
    __slots__ = ["header", "error", "display_name", "model_name", "device_firmware_version", "device_id", "device_user_id", "device_serial_number", "interface_id", "transport_layer_id", "streaming", "width", "height", "frame_rate", "pixel_format", "trigger_info", "ip_address", "mac_address"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    DEVICE_FIRMWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    DEVICE_USER_ID_FIELD_NUMBER: _ClassVar[int]
    DEVICE_SERIAL_NUMBER_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSPORT_LAYER_ID_FIELD_NUMBER: _ClassVar[int]
    STREAMING_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    FRAME_RATE_FIELD_NUMBER: _ClassVar[int]
    PIXEL_FORMAT_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_INFO_FIELD_NUMBER: _ClassVar[int]
    IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MAC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    error: _error_pb2.Error
    display_name: str
    model_name: str
    device_firmware_version: str
    device_id: str
    device_user_id: str
    device_serial_number: str
    interface_id: str
    transport_layer_id: str
    streaming: bool
    width: int
    height: int
    frame_rate: float
    pixel_format: str
    trigger_info: _containers.RepeatedCompositeFieldContainer[_trigger_info_pb2.TriggerInfo]
    ip_address: str
    mac_address: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., error: _Optional[_Union[_error_pb2.Error, _Mapping]] = ..., display_name: _Optional[str] = ..., model_name: _Optional[str] = ..., device_firmware_version: _Optional[str] = ..., device_id: _Optional[str] = ..., device_user_id: _Optional[str] = ..., device_serial_number: _Optional[str] = ..., interface_id: _Optional[str] = ..., transport_layer_id: _Optional[str] = ..., streaming: bool = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., frame_rate: _Optional[float] = ..., pixel_format: _Optional[str] = ..., trigger_info: _Optional[_Iterable[_Union[_trigger_info_pb2.TriggerInfo, _Mapping]]] = ..., ip_address: _Optional[str] = ..., mac_address: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.moveit_msgs.msg import planner_interface_description_pb2 as _planner_interface_description_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryPlannerInterfacesRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class QueryPlannerInterfacesResponse(_message.Message):
    __slots__ = ["planner_interfaces"]
    PLANNER_INTERFACES_FIELD_NUMBER: _ClassVar[int]
    planner_interfaces: _containers.RepeatedCompositeFieldContainer[_planner_interface_description_pb2.PlannerInterfaceDescription]
    def __init__(self, planner_interfaces: _Optional[_Iterable[_Union[_planner_interface_description_pb2.PlannerInterfaceDescription, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nav2_msgs/srv/is_path_valid.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.nav_msgs.msg import path_pb2 as make87__messages__ros2_dot_humble_dot_nav__msgs_dot_msg_dot_path__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/humble/nav2_msgs/srv/is_path_valid.proto\x12)make87_messages_ros2.humble.nav2_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x33make87_messages_ros2/humble/nav_msgs/msg/path.proto\"\x80\x01\n\x12IsPathValidRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12<\n\x04path\x18\x02 \x01(\x0b\x32..make87_messages_ros2.humble.nav_msgs.msg.Path\"s\n\x13IsPathValidResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08is_valid\x18\x02 \x01(\x08\x12\x1c\n\x14invalid_pose_indices\x18\x03 \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nav2_msgs.srv.is_path_valid_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ISPATHVALIDREQUEST']._serialized_start=197
  _globals['_ISPATHVALIDREQUEST']._serialized_end=325
  _globals['_ISPATHVALIDRESPONSE']._serialized_start=327
  _globals['_ISPATHVALIDRESPONSE']._serialized_end=442
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.marti_nav_msgs.msg import route_pb2 as _route_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SaveRouteRequest(_message.Message):
    __slots__ = ["header", "name", "guid", "route", "thumbnail"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    GUID_FIELD_NUMBER: _ClassVar[int]
    ROUTE_FIELD_NUMBER: _ClassVar[int]
    THUMBNAIL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    guid: str
    route: _route_pb2.Route
    thumbnail: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., guid: _Optional[str] = ..., route: _Optional[_Union[_route_pb2.Route, _Mapping]] = ..., thumbnail: _Optional[str] = ...) -> None: ...

class SaveRouteResponse(_message.Message):
    __slots__ = ["header", "success", "message"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    message: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., message: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.flexbe_msgs.msg import outcome_condition_pb2 as _outcome_condition_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StateInstantiation(_message.Message):
    __slots__ = ["state_path", "state_class", "initial_state_name", "input_keys", "output_keys", "cond_outcome", "cond_transition", "behavior_class", "parameter_names", "parameter_values", "position", "outcomes", "transitions", "autonomy", "userdata_keys", "userdata_remapping"]
    STATE_PATH_FIELD_NUMBER: _ClassVar[int]
    STATE_CLASS_FIELD_NUMBER: _ClassVar[int]
    INITIAL_STATE_NAME_FIELD_NUMBER: _ClassVar[int]
    INPUT_KEYS_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_KEYS_FIELD_NUMBER: _ClassVar[int]
    COND_OUTCOME_FIELD_NUMBER: _ClassVar[int]
    COND_TRANSITION_FIELD_NUMBER: _ClassVar[int]
    BEHAVIOR_CLASS_FIELD_NUMBER: _ClassVar[int]
    PARAMETER_NAMES_FIELD_NUMBER: _ClassVar[int]
    PARAMETER_VALUES_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    OUTCOMES_FIELD_NUMBER: _ClassVar[int]
    TRANSITIONS_FIELD_NUMBER: _ClassVar[int]
    AUTONOMY_FIELD_NUMBER: _ClassVar[int]
    USERDATA_KEYS_FIELD_NUMBER: _ClassVar[int]
    USERDATA_REMAPPING_FIELD_NUMBER: _ClassVar[int]
    state_path: str
    state_class: str
    initial_state_name: str
    input_keys: _containers.RepeatedScalarFieldContainer[str]
    output_keys: _containers.RepeatedScalarFieldContainer[str]
    cond_outcome: _containers.RepeatedScalarFieldContainer[str]
    cond_transition: _containers.RepeatedCompositeFieldContainer[_outcome_condition_pb2.OutcomeCondition]
    behavior_class: str
    parameter_names: _containers.RepeatedScalarFieldContainer[str]
    parameter_values: _containers.RepeatedScalarFieldContainer[str]
    position: _containers.RepeatedScalarFieldContainer[float]
    outcomes: _containers.RepeatedScalarFieldContainer[str]
    transitions: _containers.RepeatedScalarFieldContainer[str]
    autonomy: _containers.RepeatedScalarFieldContainer[int]
    userdata_keys: _containers.RepeatedScalarFieldContainer[str]
    userdata_remapping: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, state_path: _Optional[str] = ..., state_class: _Optional[str] = ..., initial_state_name: _Optional[str] = ..., input_keys: _Optional[_Iterable[str]] = ..., output_keys: _Optional[_Iterable[str]] = ..., cond_outcome: _Optional[_Iterable[str]] = ..., cond_transition: _Optional[_Iterable[_Union[_outcome_condition_pb2.OutcomeCondition, _Mapping]]] = ..., behavior_class: _Optional[str] = ..., parameter_names: _Optional[_Iterable[str]] = ..., parameter_values: _Optional[_Iterable[str]] = ..., position: _Optional[_Iterable[float]] = ..., outcomes: _Optional[_Iterable[str]] = ..., transitions: _Optional[_Iterable[str]] = ..., autonomy: _Optional[_Iterable[int]] = ..., userdata_keys: _Optional[_Iterable[str]] = ..., userdata_remapping: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VelCovGeodetic(_message.Message):
    __slots__ = ["header", "ros2_header", "block_header", "mode", "error", "cov_vnvn", "cov_veve", "cov_vuvu", "cov_dtdt", "cov_vnve", "cov_vnvu", "cov_vndt", "cov_vevu", "cov_vedt", "cov_vudt"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    COV_VNVN_FIELD_NUMBER: _ClassVar[int]
    COV_VEVE_FIELD_NUMBER: _ClassVar[int]
    COV_VUVU_FIELD_NUMBER: _ClassVar[int]
    COV_DTDT_FIELD_NUMBER: _ClassVar[int]
    COV_VNVE_FIELD_NUMBER: _ClassVar[int]
    COV_VNVU_FIELD_NUMBER: _ClassVar[int]
    COV_VNDT_FIELD_NUMBER: _ClassVar[int]
    COV_VEVU_FIELD_NUMBER: _ClassVar[int]
    COV_VEDT_FIELD_NUMBER: _ClassVar[int]
    COV_VUDT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    block_header: _block_header_pb2.BlockHeader
    mode: int
    error: int
    cov_vnvn: float
    cov_veve: float
    cov_vuvu: float
    cov_dtdt: float
    cov_vnve: float
    cov_vnvu: float
    cov_vndt: float
    cov_vevu: float
    cov_vedt: float
    cov_vudt: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., mode: _Optional[int] = ..., error: _Optional[int] = ..., cov_vnvn: _Optional[float] = ..., cov_veve: _Optional[float] = ..., cov_vuvu: _Optional[float] = ..., cov_dtdt: _Optional[float] = ..., cov_vnve: _Optional[float] = ..., cov_vnvu: _Optional[float] = ..., cov_vndt: _Optional[float] = ..., cov_vevu: _Optional[float] = ..., cov_vedt: _Optional[float] = ..., cov_vudt: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/moveit_msgs/srv/get_group_urdf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.moveit_msgs.msg import move_it_error_codes_pb2 as make87__messages__ros2_dot_jazzy_dot_moveit__msgs_dot_msg_dot_move__it__error__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/moveit_msgs/srv/get_group_urdf.proto\x12*make87_messages_ros2.jazzy.moveit_msgs.srv\x1a\x44make87_messages_ros2/jazzy/moveit_msgs/msg/move_it_error_codes.proto\")\n\x13GetGroupUrdfRequest\x12\x12\n\ngroup_name\x18\x01 \x01(\t\"}\n\x14GetGroupUrdfResponse\x12P\n\nerror_code\x18\x01 \x01(\x0b\x32<.make87_messages_ros2.jazzy.moveit_msgs.msg.MoveItErrorCodes\x12\x13\n\x0burdf_string\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.moveit_msgs.srv.get_group_urdf_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETGROUPURDFREQUEST']._serialized_start=181
  _globals['_GETGROUPURDFREQUEST']._serialized_end=222
  _globals['_GETGROUPURDFRESPONSE']._serialized_start=224
  _globals['_GETGROUPURDFRESPONSE']._serialized_end=349
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Lane(_message.Message):
    __slots__ = ["header", "quality", "marker_kind", "curve_model_kind", "marker_offset", "heading_angle", "curvature", "curvature_derivative", "marker_width", "view_range"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    QUALITY_FIELD_NUMBER: _ClassVar[int]
    MARKER_KIND_FIELD_NUMBER: _ClassVar[int]
    CURVE_MODEL_KIND_FIELD_NUMBER: _ClassVar[int]
    MARKER_OFFSET_FIELD_NUMBER: _ClassVar[int]
    HEADING_ANGLE_FIELD_NUMBER: _ClassVar[int]
    CURVATURE_FIELD_NUMBER: _ClassVar[int]
    CURVATURE_DERIVATIVE_FIELD_NUMBER: _ClassVar[int]
    MARKER_WIDTH_FIELD_NUMBER: _ClassVar[int]
    VIEW_RANGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    quality: int
    marker_kind: int
    curve_model_kind: int
    marker_offset: float
    heading_angle: float
    curvature: float
    curvature_derivative: float
    marker_width: float
    view_range: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., quality: _Optional[int] = ..., marker_kind: _Optional[int] = ..., curve_model_kind: _Optional[int] = ..., marker_offset: _Optional[float] = ..., heading_angle: _Optional[float] = ..., curvature: _Optional[float] = ..., curvature_derivative: _Optional[float] = ..., marker_width: _Optional[float] = ..., view_range: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IsPausedRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IsPausedResponse(_message.Message):
    __slots__ = ["paused"]
    PAUSED_FIELD_NUMBER: _ClassVar[int]
    paused: bool
    def __init__(self, paused: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PersonalDataProcessor(_message.Message):
    __slots__ = ["header", "data_source_node", "user_friendly_source_name", "data_purpose", "path"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCE_NODE_FIELD_NUMBER: _ClassVar[int]
    USER_FRIENDLY_SOURCE_NAME_FIELD_NUMBER: _ClassVar[int]
    DATA_PURPOSE_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    data_source_node: str
    user_friendly_source_name: str
    data_purpose: str
    path: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., data_source_node: _Optional[str] = ..., user_friendly_source_name: _Optional[str] = ..., data_purpose: _Optional[str] = ..., path: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_nav_msgs/msg/route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.marti_common_msgs.msg import key_value_pb2 as make87__messages__ros2_dot_rolling_dot_marti__common__msgs_dot_msg_dot_key__value__pb2
from make87_messages_ros2.rolling.marti_nav_msgs.msg import route_point_pb2 as make87__messages__ros2_dot_rolling_dot_marti__nav__msgs_dot_msg_dot_route__point__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/marti_nav_msgs/msg/route.proto\x12/make87_messages_ros2.rolling.marti_nav_msgs.msg\x1a\x42make87_messages_ros2/rolling/marti_common_msgs/msg/key_value.proto\x1a\x41make87_messages_ros2/rolling/marti_nav_msgs/msg/route_point.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xef\x01\n\x05Route\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12Q\n\x0croute_points\x18\x02 \x03(\x0b\x32;.make87_messages_ros2.rolling.marti_nav_msgs.msg.RoutePoint\x12P\n\nproperties\x18\x03 \x03(\x0b\x32<.make87_messages_ros2.rolling.marti_common_msgs.msg.KeyValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_nav_msgs.msg.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ROUTE']._serialized_start=304
  _globals['_ROUTE']._serialized_end=543
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class VectorInfoCart(_message.Message):
    __slots__ = ["nr_sv", "error", "mode", "misc", "delta_x", "delta_y", "delta_z", "delta_vx", "delta_vy", "delta_vz", "azimuth", "elevation", "reference_id", "corr_age", "signal_info"]
    NR_SV_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    MISC_FIELD_NUMBER: _ClassVar[int]
    DELTA_X_FIELD_NUMBER: _ClassVar[int]
    DELTA_Y_FIELD_NUMBER: _ClassVar[int]
    DELTA_Z_FIELD_NUMBER: _ClassVar[int]
    DELTA_VX_FIELD_NUMBER: _ClassVar[int]
    DELTA_VY_FIELD_NUMBER: _ClassVar[int]
    DELTA_VZ_FIELD_NUMBER: _ClassVar[int]
    AZIMUTH_FIELD_NUMBER: _ClassVar[int]
    ELEVATION_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_ID_FIELD_NUMBER: _ClassVar[int]
    CORR_AGE_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_INFO_FIELD_NUMBER: _ClassVar[int]
    nr_sv: int
    error: int
    mode: int
    misc: int
    delta_x: float
    delta_y: float
    delta_z: float
    delta_vx: float
    delta_vy: float
    delta_vz: float
    azimuth: int
    elevation: int
    reference_id: int
    corr_age: int
    signal_info: int
    def __init__(self, nr_sv: _Optional[int] = ..., error: _Optional[int] = ..., mode: _Optional[int] = ..., misc: _Optional[int] = ..., delta_x: _Optional[float] = ..., delta_y: _Optional[float] = ..., delta_z: _Optional[float] = ..., delta_vx: _Optional[float] = ..., delta_vy: _Optional[float] = ..., delta_vz: _Optional[float] = ..., azimuth: _Optional[int] = ..., elevation: _Optional[int] = ..., reference_id: _Optional[int] = ..., corr_age: _Optional[int] = ..., signal_info: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_extended_solution_status_pb2 as _novatel_extended_solution_status_pb2
from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_signal_mask_pb2 as _novatel_signal_mask_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NovatelXYZ(_message.Message):
    __slots__ = ["header", "novatel_msg_header", "solution_status", "position_type", "x", "y", "z", "x_sigma", "y_sigma", "z_sigma", "velocity_solution_status", "velocity_type", "x_vel", "y_vel", "z_vel", "x_vel_sigma", "y_vel_sigma", "z_vel_sigma", "base_station_id", "velocity_latency", "diff_age", "solution_age", "num_satellites_tracked", "num_satellites_used_in_solution", "num_gps_and_glonass_l1_used_in_solution", "num_gps_and_glonass_l1_and_l2_used_in_solution", "extended_solution_status", "signal_mask"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    POSITION_TYPE_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    Z_FIELD_NUMBER: _ClassVar[int]
    X_SIGMA_FIELD_NUMBER: _ClassVar[int]
    Y_SIGMA_FIELD_NUMBER: _ClassVar[int]
    Z_SIGMA_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_SOLUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    X_VEL_FIELD_NUMBER: _ClassVar[int]
    Y_VEL_FIELD_NUMBER: _ClassVar[int]
    Z_VEL_FIELD_NUMBER: _ClassVar[int]
    X_VEL_SIGMA_FIELD_NUMBER: _ClassVar[int]
    Y_VEL_SIGMA_FIELD_NUMBER: _ClassVar[int]
    Z_VEL_SIGMA_FIELD_NUMBER: _ClassVar[int]
    BASE_STATION_ID_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_LATENCY_FIELD_NUMBER: _ClassVar[int]
    DIFF_AGE_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_AGE_FIELD_NUMBER: _ClassVar[int]
    NUM_SATELLITES_TRACKED_FIELD_NUMBER: _ClassVar[int]
    NUM_SATELLITES_USED_IN_SOLUTION_FIELD_NUMBER: _ClassVar[int]
    NUM_GPS_AND_GLONASS_L1_USED_IN_SOLUTION_FIELD_NUMBER: _ClassVar[int]
    NUM_GPS_AND_GLONASS_L1_AND_L2_USED_IN_SOLUTION_FIELD_NUMBER: _ClassVar[int]
    EXTENDED_SOLUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_MASK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    solution_status: str
    position_type: str
    x: float
    y: float
    z: float
    x_sigma: float
    y_sigma: float
    z_sigma: float
    velocity_solution_status: str
    velocity_type: str
    x_vel: float
    y_vel: float
    z_vel: float
    x_vel_sigma: float
    y_vel_sigma: float
    z_vel_sigma: float
    base_station_id: str
    velocity_latency: float
    diff_age: float
    solution_age: float
    num_satellites_tracked: int
    num_satellites_used_in_solution: int
    num_gps_and_glonass_l1_used_in_solution: int
    num_gps_and_glonass_l1_and_l2_used_in_solution: int
    extended_solution_status: _novatel_extended_solution_status_pb2.NovatelExtendedSolutionStatus
    signal_mask: _novatel_signal_mask_pb2.NovatelSignalMask
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., solution_status: _Optional[str] = ..., position_type: _Optional[str] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., z: _Optional[float] = ..., x_sigma: _Optional[float] = ..., y_sigma: _Optional[float] = ..., z_sigma: _Optional[float] = ..., velocity_solution_status: _Optional[str] = ..., velocity_type: _Optional[str] = ..., x_vel: _Optional[float] = ..., y_vel: _Optional[float] = ..., z_vel: _Optional[float] = ..., x_vel_sigma: _Optional[float] = ..., y_vel_sigma: _Optional[float] = ..., z_vel_sigma: _Optional[float] = ..., base_station_id: _Optional[str] = ..., velocity_latency: _Optional[float] = ..., diff_age: _Optional[float] = ..., solution_age: _Optional[float] = ..., num_satellites_tracked: _Optional[int] = ..., num_satellites_used_in_solution: _Optional[int] = ..., num_gps_and_glonass_l1_used_in_solution: _Optional[int] = ..., num_gps_and_glonass_l1_and_l2_used_in_solution: _Optional[int] = ..., extended_solution_status: _Optional[_Union[_novatel_extended_solution_status_pb2.NovatelExtendedSolutionStatus, _Mapping]] = ..., signal_mask: _Optional[_Union[_novatel_signal_mask_pb2.NovatelSignalMask, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.type_description_interfaces.msg import field_type_pb2 as _field_type_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Field(_message.Message):
    __slots__ = ["name", "type", "default_value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: _field_type_pb2.FieldType
    default_value: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[_field_type_pb2.FieldType, _Mapping]] = ..., default_value: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ros_gz_interfaces/srv/delete_entity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ros_gz_interfaces.msg import entity_pb2 as make87__messages__ros2_dot_rolling_dot_ros__gz__interfaces_dot_msg_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/ros_gz_interfaces/srv/delete_entity.proto\x12\x32make87_messages_ros2.rolling.ros_gz_interfaces.srv\x1a?make87_messages_ros2/rolling/ros_gz_interfaces/msg/entity.proto\"a\n\x13\x44\x65leteEntityRequest\x12J\n\x06\x65ntity\x18\x01 \x01(\x0b\x32:.make87_messages_ros2.rolling.ros_gz_interfaces.msg.Entity\"\'\n\x14\x44\x65leteEntityResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ros_gz_interfaces.srv.delete_entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DELETEENTITYREQUEST']._serialized_start=191
  _globals['_DELETEENTITYREQUEST']._serialized_end=288
  _globals['_DELETEENTITYRESPONSE']._serialized_start=290
  _globals['_DELETEENTITYRESPONSE']._serialized_end=329
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ros_gz_interfaces/msg/entity_wrench.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.geometry_msgs.msg import wrench_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_wrench__pb2
from make87_messages_ros2.jazzy.ros_gz_interfaces.msg import entity_pb2 as make87__messages__ros2_dot_jazzy_dot_ros__gz__interfaces_dot_msg_dot_entity__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/jazzy/ros_gz_interfaces/msg/entity_wrench.proto\x12\x30make87_messages_ros2.jazzy.ros_gz_interfaces.msg\x1a\x39make87_messages_ros2/jazzy/geometry_msgs/msg/wrench.proto\x1a=make87_messages_ros2/jazzy/ros_gz_interfaces/msg/entity.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xdf\x01\n\x0c\x45ntityWrench\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12H\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.ros_gz_interfaces.msg.Entity\x12\x44\n\x06wrench\x18\x03 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.geometry_msgs.msg.Wrenchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ros_gz_interfaces.msg.entity_wrench_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ENTITYWRENCH']._serialized_start=299
  _globals['_ENTITYWRENCH']._serialized_end=522
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.plansys2_msgs.msg import tree_pb2 as _tree_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetProblemGoalRequest(_message.Message):
    __slots__ = ["request"]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    request: _empty_pb2.Empty
    def __init__(self, request: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...

class GetProblemGoalResponse(_message.Message):
    __slots__ = ["success", "tree", "error_info"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    TREE_FIELD_NUMBER: _ClassVar[int]
    ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    success: bool
    tree: _tree_pb2.Tree
    error_info: str
    def __init__(self, success: bool = ..., tree: _Optional[_Union[_tree_pb2.Tree, _Mapping]] = ..., error_info: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_nav_pvt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import carr_soln_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_carr__soln__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import gps_fix_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_gps__fix__pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import psmpvt_pb2 as make87__messages__ros2_dot_jazzy_dot_ublox__ubx__msgs_dot_msg_dot_psmpvt__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/ubx_nav_pvt.proto\x12-make87_messages_ros2.jazzy.ublox_ubx_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\x1a=make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/carr_soln.proto\x1a;make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/gps_fix.proto\x1a:make87_messages_ros2/jazzy/ublox_ubx_msgs/msg/psmpvt.proto\"\xac\x07\n\tUBXNavPVT\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x0c\n\x04itow\x18\x02 \x01(\r\x12\x0c\n\x04year\x18\x03 \x01(\r\x12\r\n\x05month\x18\x04 \x01(\r\x12\x0b\n\x03\x64\x61y\x18\x05 \x01(\r\x12\x0c\n\x04hour\x18\x06 \x01(\r\x12\x0b\n\x03min\x18\x07 \x01(\r\x12\x0b\n\x03sec\x18\x08 \x01(\r\x12\x12\n\nvalid_date\x18\t \x01(\x08\x12\x12\n\nvalid_time\x18\n \x01(\x08\x12\x16\n\x0e\x66ully_resolved\x18\x0b \x01(\x08\x12\x11\n\tvalid_mag\x18\x0c \x01(\x08\x12\r\n\x05t_acc\x18\r \x01(\r\x12\x0c\n\x04nano\x18\x0e \x01(\x05\x12\x46\n\x07gps_fix\x18\x0f \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.GpsFix\x12\x13\n\x0bgnss_fix_ok\x18\x10 \x01(\x08\x12\x11\n\tdiff_soln\x18\x11 \x01(\x08\x12\x42\n\x03psm\x18\x12 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.PSMPVT\x12\x16\n\x0ehead_veh_valid\x18\x13 \x01(\x08\x12J\n\tcarr_soln\x18\x14 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.CarrSoln\x12\x17\n\x0f\x63onfirmed_avail\x18\x15 \x01(\x08\x12\x16\n\x0e\x63onfirmed_date\x18\x16 \x01(\x08\x12\x16\n\x0e\x63onfirmed_time\x18\x17 \x01(\x08\x12\x0e\n\x06num_sv\x18\x18 \x01(\r\x12\x0b\n\x03lon\x18\x19 \x01(\x05\x12\x0b\n\x03lat\x18\x1a \x01(\x05\x12\x0e\n\x06height\x18\x1b \x01(\x05\x12\x0c\n\x04hmsl\x18\x1c \x01(\x05\x12\r\n\x05h_acc\x18\x1d \x01(\r\x12\r\n\x05v_acc\x18\x1e \x01(\r\x12\r\n\x05vel_n\x18\x1f \x01(\x05\x12\r\n\x05vel_e\x18  \x01(\x05\x12\r\n\x05vel_d\x18! \x01(\x05\x12\x0f\n\x07g_speed\x18\" \x01(\x05\x12\x10\n\x08head_mot\x18# \x01(\x05\x12\r\n\x05s_acc\x18$ \x01(\r\x12\x10\n\x08head_acc\x18% \x01(\r\x12\r\n\x05p_dop\x18& \x01(\r\x12\x13\n\x0binvalid_llh\x18\' \x01(\x08\x12\x10\n\x08head_veh\x18( \x01(\x05\x12\x0f\n\x07mag_dec\x18) \x01(\x05\x12\x0f\n\x07mag_acc\x18* \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ublox_ubx_msgs.msg.ubx_nav_pvt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UBXNAVPVT']._serialized_start=353
  _globals['_UBXNAVPVT']._serialized_end=1293
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/nao_lola_command_msgs/msg/head_leds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/nao_lola_command_msgs/msg/head_leds.proto\x12\x36make87_messages_ros2.rolling.nao_lola_command_msgs.msg\"\x1f\n\x08HeadLeds\x12\x13\n\x0bintensities\x18\x01 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.nao_lola_command_msgs.msg.head_leds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_HEADLEDS']._serialized_start=130
  _globals['_HEADLEDS']._serialized_end=161
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.irobot_create_msgs.msg import button_pb2 as _button_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InterfaceButtons(_message.Message):
    __slots__ = ["header", "button_1", "button_power", "button_2"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BUTTON_1_FIELD_NUMBER: _ClassVar[int]
    BUTTON_POWER_FIELD_NUMBER: _ClassVar[int]
    BUTTON_2_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    button_1: _button_pb2.Button
    button_power: _button_pb2.Button
    button_2: _button_pb2.Button
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., button_1: _Optional[_Union[_button_pb2.Button, _Mapping]] = ..., button_power: _Optional[_Union[_button_pb2.Button, _Mapping]] = ..., button_2: _Optional[_Union[_button_pb2.Button, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DemuxDeleteRequest(_message.Message):
    __slots__ = ["topic"]
    TOPIC_FIELD_NUMBER: _ClassVar[int]
    topic: str
    def __init__(self, topic: _Optional[str] = ...) -> None: ...

class DemuxDeleteResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrVehicle5(_message.Message):
    __slots__ = ["header", "ros2_header", "oversteer_understeer", "yaw_rate_bias_shift", "beamwidth_vert", "funnel_offset_left", "funnel_offset_right", "cw_blockage_threshold", "distance_rear_axle", "wheelbase", "steering_gear_ratio"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    OVERSTEER_UNDERSTEER_FIELD_NUMBER: _ClassVar[int]
    YAW_RATE_BIAS_SHIFT_FIELD_NUMBER: _ClassVar[int]
    BEAMWIDTH_VERT_FIELD_NUMBER: _ClassVar[int]
    FUNNEL_OFFSET_LEFT_FIELD_NUMBER: _ClassVar[int]
    FUNNEL_OFFSET_RIGHT_FIELD_NUMBER: _ClassVar[int]
    CW_BLOCKAGE_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_REAR_AXLE_FIELD_NUMBER: _ClassVar[int]
    WHEELBASE_FIELD_NUMBER: _ClassVar[int]
    STEERING_GEAR_RATIO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    oversteer_understeer: int
    yaw_rate_bias_shift: bool
    beamwidth_vert: float
    funnel_offset_left: float
    funnel_offset_right: float
    cw_blockage_threshold: float
    distance_rear_axle: int
    wheelbase: int
    steering_gear_ratio: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., oversteer_understeer: _Optional[int] = ..., yaw_rate_bias_shift: bool = ..., beamwidth_vert: _Optional[float] = ..., funnel_offset_left: _Optional[float] = ..., funnel_offset_right: _Optional[float] = ..., cw_blockage_threshold: _Optional[float] = ..., distance_rear_axle: _Optional[int] = ..., wheelbase: _Optional[int] = ..., steering_gear_ratio: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.ouster_msgs.msg import metadata_pb2 as _metadata_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetMetadataRequest(_message.Message):
    __slots__ = ["header"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...

class GetMetadataResponse(_message.Message):
    __slots__ = ["header", "metadata"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    metadata: _metadata_pb2.Metadata
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., metadata: _Optional[_Union[_metadata_pb2.Metadata, _Mapping]] = ...) -> None: ...
